@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 #
-# Copyright (C) 2020 Sébastien Helleu <flashcode@flashtux.org>
+# Copyright (C) 2020-2021 Sébastien Helleu <flashcode@flashtux.org>
 #
 # This file is part of Tasksched.
 #
@@ -21,7 +21,9 @@
 """Task scheduler with automatic resource leveling."""
 
 from tasksched.tasksched import *  # noqa
+from tasksched.parser import *  # noqa
 from tasksched.project import *  # noqa
 from tasksched.workplan import *  # noqa
 from tasksched.workplan_text import *  # noqa
+from tasksched.workplan_html import *  # noqa
 from tasksched.utils import *  # noqa
